<?php 
/**
 * Main plugin file. This plugin adds useful admin links and resources for the Jigoshop Shop Plugin to the WordPress Toolbar / Admin Bar.
 *
 * @package JigoshopAdminBarAddition
 * @author David Decker
 *
 * @credits Inspired and based on the plugin "WooThemes Admin Bar Addition" by Remkus de Vries @defries.
 * @link http://remkusdevries.com/
 * @link http://twitter.com/#!/defries
 *
 * Plugin Name: Jigoshop Admin Bar Addition
 * Plugin URI: http://genesisthemes.de/en/wp-plugins/jigoshop-admin-bar-addition/
 * Description: This plugin adds useful admin links and resources for the Jigoshop Shop Plugin to the WordPress Toolbar / Admin Bar.
 * Version: 1.6
 * Author: David Decker - DECKERWEB
 * Author URI: http://deckerweb.de/
 * License: GPLv2
 * Text Domain: jsaba
 * Domain Path: /languages/
 */

/**
 * Setting constants
 *
 * @since 1.0
 */
define( 'JSABA_PLUGIN_BASEDIR', dirname( plugin_basename( __FILE__ ) ) );


/**
 * Load the text domain for translation of the plugin
 * 
 * @since 1.0
 */
load_plugin_textdomain( 'jsaba', false, JSABA_PLUGIN_BASEDIR . '/languages/' );


add_filter( 'plugin_row_meta', 'ddw_jigoshop_aba_plugin_links', 10, 2 );
/**
 * Add various support links to plugin page
 *
 * @since 1.0
 */
function ddw_jigoshop_aba_plugin_links( $jsaba_links, $jsaba_file ) {

	if ( !current_user_can( 'install_plugins' ))
		return $jsaba_links;

	if ( $jsaba_file == JSABA_PLUGIN_BASEDIR . '/jigoshop-admin-bar-addition.php' ) {
		$jsaba_links[] = '<a href="http://wordpress.org/extend/plugins/jigoshop-admin-bar-addition/faq/" target="_new" title="' . __( 'FAQ', 'jsaba' ) . '">' . __( 'FAQ', 'jsaba' ) . '</a>';
		$jsaba_links[] = '<a href="http://wordpress.org/tags/jigoshop-admin-bar-addition?forum_id=10" target="_new" title="' . __( 'Support', 'jsaba' ) . '">' . __( 'Support', 'jsaba' ) . '</a>';
		$jsaba_links[] = '<a href="' . __( 'http://genesisthemes.de/en/donate/', 'jsaba' ) . '" target="_new" title="' . __( 'Donate', 'jsaba' ) . '">' . __( 'Donate', 'jsaba' ) . '</a>';
	}

	return $jsaba_links;
}


add_action( 'admin_bar_menu', 'ddw_jigoshop_aba_admin_bar_menu', 98 );
/**
 * Add new menu items to the WP Admin Bar.
 * 
 * @since 1.0
 *
 * @global mixed $wp_admin_bar 
 */
function ddw_jigoshop_aba_admin_bar_menu() {
	global $wp_admin_bar;

	// Required WordPress cabability to display new admin bar entry
	if ( !current_user_can( 'install_plugins' ) || !is_admin_bar_showing() )
		return;

	// Set unique prefix
	$prefix = 'ddw-jigoshop-';
	
	// Create parent menu item references
	$jigoshopbar = $prefix . 'admin-bar';
	$support = $prefix . 'jssupport';
	$jsknowledgebase = $prefix . 'jsknowledgebase';
	$jigoshopsites = $prefix . 'jigoshopsites';
	$settings = $prefix . 'settings';
	$products = $prefix . 'products';
	$productvariants = $prefix . 'productvariants';
	$coupons = $prefix . 'coupons';
	$orders = $prefix . 'orders';
	$extensions = $prefix . 'extensions';
	$extjsswao = $prefix . 'extjsswao';
	$extpideal = $prefix . 'extpideal';
	
	// Display these items also when Jigoshop plugin is not installed
	$menu_items = array(
		'jssupport' => array(
			'parent' => $jigoshopbar,
			'title'  => __( 'Jigoshop Support', 'jsaba' ),
			'href'   => 'http://forum.jigoshop.com/',
			'meta'   => array( 'title' => __( 'Jigoshop Support', 'jsaba' ) )
		),
		'jsforum' => array(
			'parent' => $support,
			'title'  => __( 'Jigoshop Public Forum', 'jsaba' ),
			'href'   => 'http://forum.jigoshop.com/discussions',
			'meta'   => array( 'title' => __( 'Jigoshop Public Forum', 'jsaba' ) )
		),
		'jssupportpremium' => array(
			'parent' => $support,
			'title'  => __( 'Jigoshop Premium Support', 'jsaba' ),
			'href'   => 'http://jigoshop.com/support/',
			'meta'   => array( 'title' => __( 'Jigoshop Premium Support', 'jsaba' ) )
		),
		'jssupportwporg' => array(
			'parent' => $support,
			'title'  => __( 'Free Support Forum (WP.org)', 'jsaba' ),
			'href'   => 'http://wordpress.org/tags/jigoshop?forum_id=10',
			'meta'   => array( 'title' => __( 'Free Support Forum (WP.org)', 'jsaba' ) )
		),
		'jsknowledgebase' => array(
			'parent' => $jigoshopbar,
			'title'  => __( 'Jigoshop Knowledge Base', 'jsaba' ),
			'href'   => 'http://forum.jigoshop.com/kb',
			'meta'   => array( 'title' => __( 'Jigoshop Knowledge Base', 'jsaba' ) )
		),
		'jigoshopsites' => array(
			'parent' => $jigoshopbar,
			'title'  => __( 'Jigoshop HQ', 'jsaba' ),
			'href'   => 'http://jigoshop.com/',
			'meta'   => array( 'title' => __( 'Jigoshop HQ', 'jsaba' ) )
		),
		'jsblog' => array(
			'parent' => $jigoshopsites,
			'title'  => __( 'Official Blog', 'jsaba' ),
			'href'   => 'http://jigoshop.com/blog/',
			'meta'   => array( 'title' => __( 'Official Blog', 'jsaba' ) )
		),
		'jsshowcase' => array(
			'parent' => $jigoshopsites,
			'title'  => __( 'Showcase', 'jsaba' ),
			'href'   => 'http://jigoshop.com/showcase/',
			'meta'   => array( 'title' => __( 'Showcase', 'jsaba' ) )
		),
		'jsbugs' => array(
			'parent' => $jigoshopsites,
			'title'  => __( 'Issues &amp; Bug Reports', 'jsaba' ),
			'href'   => 'https://github.com/jigoshop/jigoshop/issues',
			'meta'   => array( 'title' => __( 'Issues &amp; Bug Reports', 'jsaba' ) )
		),
		'jsdev' => array(
			'parent' => $jigoshopsites,
			'title'  => __( 'GitHub Repository Developer Center', 'jsaba' ),
			'href'   => 'https://github.com/jigoshop/jigoshop',
			'meta'   => array( 'title' => __( 'GitHub Repository Developer Center', 'jsaba' ) )
		),
		'jsextensions' => array(
			'parent' => $jigoshopsites,
			'title'  => __( 'Official Jigoshop Extensions', 'jsaba' ),
			'href'   => 'http://jigoshop.com/extend/',
			'meta'   => array( 'title' => __( 'Official Jigoshop Extensions', 'jsaba' ) )
		),
		'jsplugins' => array(
			'parent' => $jigoshopsites,
			'title'  => __( 'More free plugins/extensions at WP.org', 'jsaba' ),
			'href'   => 'http://wordpress.org/extend/plugins/search.php?q=jigoshop',
			'meta'   => array( 'title' => __( 'More free plugins/extensions at WP.org', 'jsaba' ) )
		),
		'jsvideo' => array(
			'parent' => $support,
			'title'  => __( 'Official Video Channel', 'jsaba' ),
			'href'   => 'http://www.youtube.com/jigoshop',
			'meta'   => array( 'title' => __( 'Official Video Channel', 'jsaba' ) )
		),
		'jsvideomore' => array(
			'parent' => $support,
			'title'  => __( 'More Videos', 'jsaba' ),
			'href'   => 'http://vimeo.com/user5178120/videos',
			'meta'   => array( 'title' => __( 'More Videos', 'jsaba' ) )
		),
	);

	// Display link to specific language forum only for these locales: de_DE, de_AT, de_CH, de_LU
	if ( get_locale() == 'de_DE' || get_locale() == 'de_AT' || get_locale() == 'de_CH' || get_locale() == 'de_LU' ) {
		$menu_items['forum-de'] = array(
			'parent' => $jigoshopbar,
			'title'  => __( 'German Support Forum', 'jsaba' ),
			'href'   => 'http://jigoshop.de/forum/',
			'meta'   => array( 'title' => __( 'German Support Forum', 'jsaba' ) )
		);
	}

	// Display links to language packs only for these locales: de_DE, de_AT, de_CH, de_LU
	if ( get_locale() == 'de_DE' || get_locale() == 'de_AT' || get_locale() == 'de_CH' || get_locale() == 'de_LU' ) {
		$menu_items['languages-de'] = array(
			'parent' => $jigoshopbar,
			'title'  => __( 'German language files', 'jsaba' ),
			'href'   => 'http://deckerweb.de/material/sprachdateien/jigoshop-und-extensions/',
			'meta'   => array( 'title' => __( 'German language files', 'jsaba' ) )
		);
	}

	// Show these items only if Jigoshop plugin is actually installed
	if ( function_exists ( 'jigoshop_init' ) ) {
		$menu_items['settings'] = array(
			'parent' => $jigoshopbar,
			'title'  => __( 'Shop Overview &amp; Reports', 'jsaba' ),
			'href'   => admin_url( 'admin.php?page=jigoshop' ),
			'meta'   => array( 'target' => '', 'title' => __( 'Shop Overview &amp; Reports', 'jsaba' ) )
		);
		$menu_items['s-general-settings'] = array(
			'parent' => $settings,
			'title'  => __( 'General Settings', 'jsaba' ),
			'href'   => admin_url( 'admin.php?page=settings' ),
			'meta'   => array( 'target' => '', 'title' => __( 'General Settings', 'jsaba' ) )
		);
		$menu_items['s-widgets'] = array(
			'parent' => $settings,
			'title'  => __( 'Jigoshop Widgets', 'jsaba' ),
			'href'   => admin_url( 'widgets.php' ),
			'meta'   => array( 'target' => '', 'title' => __( 'Jigoshop Widgets', 'jsaba' ) )
		);
		$menu_items['s-sysinfo'] = array(
			'parent' => $settings,
			'title'  => __( 'System &amp Server Info', 'jsaba' ),
			'href'   => admin_url( 'admin.php?page=sysinfo' ),
			'meta'   => array( 'target' => '', 'title' => __( 'System &amp Server Info', 'jsaba' ) )
		);
		$menu_items['products'] = array(
			'parent' => $jigoshopbar,
			'title'  => __( 'Products', 'jsaba' ),
			'href'   => admin_url( 'edit.php?post_type=product' ),
			'meta'   => array( 'target' => '', 'title' => __( 'Products', 'jsaba' ) )
		);
		$menu_items['p-add-product'] = array(
			'parent' => $products,
			'title'  => __( 'Add new product', 'jsaba' ),
			'href'   => admin_url( 'post-new.php?post_type=product' ),
			'meta'   => array( 'target' => '', 'title' => __( 'Add new product', 'jsaba' ) )
		);
		$menu_items['p-product-categories'] = array(
			'parent' => $products,
			'title'  => __( 'Product Categories', 'jsaba' ),
			'href'   => admin_url( 'edit-tags.php?taxonomy=product_cat&post_type=product' ),
			'meta'   => array( 'target' => '', 'title' => __( 'Product Categories', 'jsaba' ) )
		);
		$menu_items['p-product-tags'] = array(
			'parent' => $products,
			'title'  => __( 'Product Tags', 'jsaba' ),
			'href'   => admin_url( 'edit-tags.php?taxonomy=product_tag&post_type=product' ),
			'meta'   => array( 'target' => '', 'title' => __( 'Product Tags', 'jsaba' ) )
		);
		$menu_items['productvariants'] = array(
			'parent' => $products,
			'title'  => __( 'Product Variants', 'jsaba' ),
			'href'   => admin_url( 'edit.php?post_type=product_variation' ),
			'meta'   => array( 'target' => '', 'title' => __( 'Product Variants', 'jsaba' ) )
		);
		$menu_items['p-add-product-variant'] = array(
			'parent' => $productvariants,
			'title'  => __( 'Add new product variant', 'jsaba' ),
			'href'   => admin_url( 'post-new.php?post_type=product_variation' ),
			'meta'   => array( 'target' => '', 'title' => __( 'Add new product variant', 'jsaba' ) )
		);
		$menu_items['p-product-variants'] = array(
			'parent' => $products,
			'title'  => __( 'Attributes (for Product Variants)', 'jsaba' ),
			'href'   => admin_url( 'edit.php?post_type=product&page=attributes' ),
			'meta'   => array( 'target' => '', 'title' => __( 'Attributes (for Product Variants)', 'jsaba' ) )
		);
		$menu_items['orders'] = array(
			'parent' => $jigoshopbar,
			'title'  => __( 'Orders', 'jsaba' ),
			'href'   => admin_url( 'edit.php?post_type=shop_order' ),
			'meta'   => array( 'target' => '', 'title' => __( 'Orders', 'jsaba' ) )
		);
		$menu_items['o-add-order'] = array(
			'parent' => $orders,
			'title'  => __( 'Add new order', 'jsaba' ),
			'href'   => admin_url( 'post-new.php?post_type=shop_order' ),
			'meta'   => array( 'target' => '', 'title' => __( 'Add new order', 'jsaba' ) )
		);
		/**
		 * Display last main item in the menu for active extensions/plugins
		 * ATTENTION: This is where plugins/extensions hook in on the sub-level hierarchy
		 *
		 * @since 1.0
		 */
		$menu_items['extensions'] = array(
			'parent' => $jigoshopbar,
			'title'  => __( 'Active Extensions', 'jsaba' ),
			'href'   => admin_url( 'plugins.php' ),
			'meta'   => array( 'target' => '', 'title' => __( 'Manage Exchange Rates', 'jsaba' ) )
		);
	}


	/**
	 * Display links to active Jigoshop specific themes settings' pages
	 *
	 * @since 1.0
	 */

		/**
		 * Display link to active Jigotheme theme settings page (premium, by Jigowatt/Jigoshop)
		 *
		 * @since 1.0
		 */
		if ( get_current_theme() == 'Jigotheme' || get_template() == 'jigotheme' ) {
			$menu_items['jigotheme-settings'] = array(
				'parent' => $jigoshopbar,
				'title'  => __( 'Jigotheme Settings', 'jsaba' ),
				'href'   => admin_url( 'admin.php?page=theme-config.php' ),
				'meta'   => array( 'target' => '', 'title' => __( 'Jigotheme Settings', 'jsaba' ) )
			);
		}

		/**
		 * Display link to active Corellian theme settings page (premium, by Jigowatt/Jigoshop)
		 *
		 * @since 1.0
		 */
		if ( get_current_theme() == 'Corellian' || get_template() == 'corellian' ) {
			$menu_items['corellian-settings'] = array(
				'parent' => $jigoshopbar,
				'title'  => __( 'Corellian Theme Settings', 'jsaba' ),
				'href'   => admin_url( 'admin.php?page=theme-config.php' ),
				'meta'   => array( 'target' => '', 'title' => __( 'Corellian Theme Settings', 'jsaba' ) )
			);
		}

		/**
		 * Display link to active Origin theme settings page (premium, by Jigowatt/Jigoshop)
		 *
		 * @since 1.0
		 */
		if ( get_current_theme() == 'Origin' || get_template() == 'origin' ) {
			$menu_items['origin-settings'] = array(
				'parent' => $jigoshopbar,
				'title'  => __( 'Origin Theme Settings', 'jsaba' ),
				'href'   => admin_url( 'admin.php?page=theme-config.php' ),
				'meta'   => array( 'target' => '', 'title' => __( 'Origin Theme Settings', 'jsaba' ) )
			);
		}

		/**
		 * Display link to active Serenum theme settings page (premium, by Jigowatt/Jigoshop)
		 *
		 * @since 1.5
		 */
		if ( get_current_theme() == 'Serenum' || get_template() == 'serenum' ) {
			$menu_items['serenum-settings'] = array(
				'parent' => $jigoshopbar,
				'title'  => __( 'Serenum Theme Settings', 'jsaba' ),
				'href'   => admin_url( 'admin.php?page=theme-config.php' ),
				'meta'   => array( 'target' => '', 'title' => __( 'Serenum Theme Settings', 'jsaba' ) )
			);
		}

		/**
		 * Display link to active Overload theme settings page (premium, by Jigowatt/Jigoshop)
		 *
		 * @since 1.5
		 */
		if ( get_current_theme() == 'Overload' || get_template() == 'overload' ) {
			$menu_items['overload-settings'] = array(
				'parent' => $jigoshopbar,
				'title'  => __( 'Overload Theme Settings', 'jsaba' ),
				'href'   => admin_url( 'admin.php?page=theme-config.php' ),
				'meta'   => array( 'target' => '', 'title' => __( 'Overload Theme Settings', 'jsaba' ) )
			);
		}

		/**
		 * Display link to active Skeleton theme settings page (free, by Simple Themes)
		 *
		 * @since 1.1
		 */
		if ( get_current_theme() == 'Skeleton' || get_template() == 'skeleton' ) {
			$menu_items['skeleton-settings'] = array(
				'parent' => $jigoshopbar,
				'title'  => __( 'Skeleton Theme Settings', 'jsaba' ),
				'href'   => admin_url( 'themes.php?page=options-framework' ),
				'meta'   => array( 'target' => '', 'title' => __( 'Skeleton Theme Settings', 'jsaba' ) )
			);
		}

		/**
		 * Display link to active Animal House theme settings page (premium, by JamiGibbs at ThemeForest)
		 *
		 * @since 1.1
		 */
		if ( get_current_theme() == 'Animal House' || get_template() == 'animalhouse' || get_template() == 'animal-house' ) {
			$menu_items['animalhouse-settings'] = array(
				'parent' => $jigoshopbar,
				'title'  => __( 'Animal House Theme Settings', 'jsaba' ),
				'href'   => admin_url( 'themes.php?page=options-framework' ),
				'meta'   => array( 'target' => '', 'title' => __( 'Animal House Theme Settings', 'jsaba' ) )
			);
		}

		/**
		 * Display link to active FreshShop theme settings page (premium, by JamiGibbs at ThemeForest)
		 *
		 * @since 1.1
		 */
		if ( get_current_theme() == 'FreshShop' || get_template() == 'freshshop' ) {
			$menu_items['freshshop-settings'] = array(
				'parent' => $jigoshopbar,
				'title'  => __( 'FreshShop Theme Settings', 'jsaba' ),
				'href'   => admin_url( 'themes.php?page=options-framework' ),
				'meta'   => array( 'target' => '', 'title' => __( 'FreshShop Theme Settings', 'jsaba' ) )
			);
		}

		/**
		 * Display link to active Sommerce theme settings page (premium, by Sara_p at ThemeForest)
		 *
		 * @since 1.4
		 */
		if ( get_current_theme() == 'Sommerce' || get_template() == 'sommerce' ) {
			$menu_items['sommerce-settings'] = array(
				'parent' => $jigoshopbar,
				'title'  => __( 'Sommerce Theme Settings', 'jsaba' ),
				'href'   => admin_url( 'themes.php?page=yiw_panel' ),
				'meta'   => array( 'target' => '', 'title' => __( 'Sommerce Theme Settings', 'jsaba' ) )
			);
		}

		/**
		 * Display link to active Dotos theme settings page (free, by Tung Do at DevPress Themes)
		 *
		 * @since 1.5
		 */
		if ( get_current_theme() == 'Dotos' || get_template() == 'dotos' ) {
			$menu_items['dotos-settings'] = array(
				'parent' => $jigoshopbar,
				'title'  => __( 'Dotos Theme Settings', 'jsaba' ),
				'href'   => admin_url( 'themes.php?page=theme-settings' ),
				'meta'   => array( 'target' => '', 'title' => __( 'Dotos Theme Settings', 'jsaba' ) )
			);
		}

		/**
		 * Display link to active Good theme settings page (free, by Tung Do at DevPress Themes)
		 *
		 * @since 1.6
		 */
		if ( get_current_theme() == 'Good' || get_template() == 'good' ) {
			$menu_items['good-settings'] = array(
				'parent' => $jigoshopbar,
				'title'  => __( 'Good Theme Settings', 'jsaba' ),
				'href'   => admin_url( 'themes.php?page=theme-settings' ),
				'meta'   => array( 'target' => '', 'title' => __( 'Good Theme Settings', 'jsaba' ) )
			);
		}

		/**
		 * Display link to active Suffusion theme settings page (free, by Sayontan Sinha)
		 * Display link to active Suffusion Commerce Pack integration plugin settings/info page (free, by Sayontan Sinha)
		 *
		 * @since 1.6
		 */
		if ( get_current_theme() == 'Suffusion' || get_template() == 'suffusion' ) {
			$menu_items['suffusion-settings'] = array(
				'parent' => $jigoshopbar,
				'title'  => __( 'Suffusion Theme Settings', 'jsaba' ),
				'href'   => admin_url( 'themes.php?page=theme-settings' ),
				'meta'   => array( 'target' => '', 'title' => __( 'Suffusion Theme Settings', 'jsaba' ) )
			);
			/**
			 * Display link to active Suffusion Commerce Pack integration plugin settings/info page (free, by Sayontan Sinha)
			 *
			 * @since 1.6
			 */
			if ( class_exists( 'Suffusion_Commerce_Pack' ) ) {
				$menu_items['ext-suffusion-pack'] = array(
					'parent' => $extensions,
					'title'  => __( 'Suffusion Commerce Pack', 'jsaba' ),
					'href'   => admin_url( 'themes.php?page=suffusion-options-manager' ),
					'meta'   => array( 'target' => '', 'title' => __( 'Suffusion Commerce Pack', 'jsaba' ) )
				);
			}
		}

		/**
		 * Display link to active Wardrobe theme settings page (premium, by ColorLabs & Company)
		 *
		 * @since 1.6
		 */
		if ( get_current_theme() == 'Wardrobe' || get_template() == 'wardrobe' ) {
			$menu_items['wardrobe-settings'] = array(
				'parent' => $jigoshopbar,
				'title'  => __( 'Wardrobe Theme Settings', 'jsaba' ),
				'href'   => admin_url( 'admin.php?page=colabsthemes_options' ),
				'meta'   => array( 'target' => '', 'title' => __( 'Wardrobe Theme Settings', 'jsaba' ) )
			);
		}


	/**
	 * Display links to active Jigoshop plugins/extensions settings' pages
	 *
	 * @since 1.2
	 */

		/**
		 * Multi Currency Lite For Jigoshop settings page (free, by Steven Clark at GitHub)
		 *
		 * @since 1.2
		 */
		if ( class_exists( 'Jigoshop_Mutli_Currency' ) ) {
			$menu_items['ext-multicurrency-lite'] = array(
				'parent' => $extensions,
				'title'  => __( 'Manage Exchange Rates', 'jsaba' ),
				'href'   => admin_url( 'admin.php?page=jigoshop_exchange_rates_settings' ),
				'meta'   => array( 'target' => '', 'title' => __( 'Manage Exchange Rates', 'jsaba' ) )
			);
			$menu_items['s-multicurrency-lite'] = array(
				'parent' => $settings,
				'title'  => __( 'Manage Exchange Rates', 'jsaba' ),
				'href'   => admin_url( 'admin.php?page=jigoshop_exchange_rates_settings' ),
				'meta'   => array( 'target' => '', 'title' => __( 'Manage Exchange Rates', 'jsaba' ) )
			);
		}

		/**
		 * Jigoshop Additional Taxonomy Content settings page (free, by Steven Clark at GitHub)
		 *
		 * @since 1.5
		 */
		if ( class_exists( 'Jigoshop_Additonal_Taxonomy_Content' ) ) {
			$menu_items['ext-additional-taxcontent'] = array(
				'parent' => $extensions,
				'title'  => __( 'Additional Taxonomy Content', 'jsaba' ),
				'href'   => admin_url( 'edit.php?post_type=product&page=jigoshop_taxonomy_settings' ),
				'meta'   => array( 'target' => '', 'title' => __( 'Additional Taxonomy Content', 'jsaba' ) )
			);
			$menu_items['p-additional-taxcontent'] = array(
				'parent' => $products,
				'title'  => __( 'Additional Taxonomy Content', 'jsaba' ),
				'href'   => admin_url( 'edit.php?post_type=product&page=jigoshop_taxonomy_settings' ),
				'meta'   => array( 'target' => '', 'title' => __( 'Additional Taxonomy Content', 'jsaba' ) )
			);
		}

		/**
		 * Jigoshop Delivery Notes settings page (free, by Steven Clark + piffpaffpuff at GitHub)
		 *
		 * @since 1.2
		 */
		if ( class_exists( 'Jigoshop_Delivery_Notes' ) ) {
			$menu_items['ext-delivery-notes'] = array(
				'parent' => $extensions,
				'title'  => __( 'Delivery Notes Settings', 'jsaba' ),
				'href'   => admin_url( 'edit.php?post_type=shop_order&page=jigoshop_delivery_notes_settings' ),
				'meta'   => array( 'target' => '', 'title' => __( 'Delivery Notes Settings', 'jsaba' ) )
			);
			$menu_items['o-delivery-notes'] = array(
				'parent' => $orders,
				'title'  => __( 'Delivery Notes Settings', 'jsaba' ),
				'href'   => admin_url( 'edit.php?post_type=shop_order&page=jigoshop_delivery_notes_settings' ),
				'meta'   => array( 'target' => '', 'title' => __( 'Delivery Notes Settings', 'jsaba' ) )
			);
		}

		/**
		 * Jigoshop Software Add-On settings pages (free, by Joachim Kudish at GitHub)
		 *
		 * @since 1.2
		 */
		if ( class_exists( 'jigoshop_software' ) ) {
			$menu_items['extjsswao'] = array(
				'parent' => $extensions,
				'title'  => __( 'Jigoshop Software Add-On', 'jsaba' ),
				'href'   => admin_url( '' ),
				'meta'   => array( 'target' => '', 'title' => __( 'Jigoshop Software Add-On', 'jsaba' ) )
			);
			$menu_items['extjsswao-stats'] = array(
				'parent' => $extjsswao,
				'title'  => __( 'Stats', 'jsaba' ),
				'href'   => admin_url( 'admin.php?page=jgs_stats' ),
				'meta'   => array( 'target' => '', 'title' => __( 'Stats', 'jsaba' ) )
			);
			$menu_items['ext-software-addon-stats'] = array(
				'parent' => $settings,
				'title'  => __( 'Software Add-On: Stats', 'jsaba' ),
				'href'   => admin_url( 'admin.php?page=jgs_stats' ),
				'meta'   => array( 'target' => '', 'title' => __( 'Software Add-On: Stats', 'jsaba' ) )
			);
			$menu_items['extjsswao-import'] = array(
				'parent' => $extjsswao,
				'title'  => __( 'Import', 'jsaba' ),
				'href'   => admin_url( 'admin.php?page=jgs_import' ),
				'meta'   => array( 'target' => '', 'title' => __( 'Import', 'jsaba' ) )
			);
			$menu_items['ext-software-addon-import'] = array(
				'parent' => $settings,
				'title'  => __( 'Software Add-On: Import', 'jsaba' ),
				'href'   => admin_url( 'admin.php?page=jgs_import' ),
				'meta'   => array( 'target' => '', 'title' => __( 'Software Add-On: Import', 'jsaba' ) )
			);
		}


		/**
		 * Pronamic iDEAL settings pages (free, by Pronamic)
		 *
		 * @since 1.6
		 */
		if ( ( function_exists( 'is_plugin_active' ) && is_plugin_active( 'pronamic-ideal/pronamic-ideal.php' ) ) || class_exists( 'Pronamic_IDeal_IDeal' ) ) {
			$menu_items['extpideal'] = array(
				'parent' => $extensions,
				'title'  => __( 'Pronamic iDEAL Payment Gateway', 'jsaba' ),
				'href'   => admin_url( 'admin.php?page=pronamic_ideal' ),
				'meta'   => array( 'target' => '', 'title' => __( 'Pronamic iDEAL Payment Gateway', 'jsaba' ) )
			);
			$menu_items['ext-pideal-payments'] = array(
				'parent' => $extpideal,
				'title'  => __( 'Payments', 'jsaba' ),
				'href'   => admin_url( 'admin.php?page=pronamic_ideal_payments' ),
				'meta'   => array( 'target' => '', 'title' => __( 'Payments', 'jsaba' ) )
			);
			$menu_items['ext-pideal-settings'] = array(
				'parent' => $extpideal,
				'title'  => __( 'Settings', 'jsaba' ),
				'href'   => admin_url( 'admin.php?page=pronamic_ideal_settings' ),
				'meta'   => array( 'target' => '', 'title' => __( 'Settings', 'jsaba' ) )
			);
			$menu_items['ext-pideal-pages-generator'] = array(
				'parent' => $extpideal,
				'title'  => __( 'Pages Generator', 'jsaba' ),
				'href'   => admin_url( 'admin.php?page=pronamic_ideal_pages_generator' ),
				'meta'   => array( 'target' => '', 'title' => __( 'Pages Generator', 'jsaba' ) )
			);
			$menu_items['ext-pideal-variants'] = array(
				'parent' => $extpideal,
				'title'  => __( 'Variants', 'jsaba' ),
				'href'   => admin_url( 'admin.php?page=pronamic_ideal_variants' ),
				'meta'   => array( 'target' => '', 'title' => __( 'Variants', 'jsaba' ) )
			);
			$menu_items['ext-pideal-documentation'] = array(
				'parent' => $extpideal,
				'title'  => __( 'Documentation', 'jsaba' ),
				'href'   => admin_url( 'admin.php?page=pronamic_ideal_documentation' ),
				'meta'   => array( 'target' => '', 'title' => __( 'Documentation', 'jsaba' ) )
			);
		}


	// Allow menu items to be filtered, but pass in parent menu item IDs
	$menu_items = (array) apply_filters( 'ddw_jigoshop_aba_menu_items', $menu_items, $prefix, $jigoshopbar, $support, $jscodex, $jigoshopsites, $settings, $products, $productvariants, $coupons, $orders, $reports, $extensions, $extjsswao, $extpideal );


	// Add the top-level item
	$wp_admin_bar->add_menu( array(
		'id'    => $jigoshopbar,
		'title' => __( 'Jigoshop', 'jsaba' ),
		'href'  => admin_url( 'admin.php?page=jigoshop' ),
		'meta'  => array( 'class' => 'icon-jigoshop', 'title' => __( 'Jigoshop', 'jsaba' ) )
	) );


	// Loop through the menu items
	foreach ( $menu_items as $id => $menu_item ) {
		
		// Add in the item ID
		$menu_item['id'] = $prefix . $id;

		// Add meta target to each item where it's not already set, so links open in new window/tab
		if ( ! isset( $menu_item['meta']['target'] ) )		
			$menu_item['meta']['target'] = '_blank';

		// Add class to links that open up in a new window/tab
		if ( '_blank' === $menu_item['meta']['target'] ) {
			if ( ! isset( $menu_item['meta']['class'] ) )
				$menu_item['meta']['class'] = '';
			$menu_item['meta']['class'] .= $prefix . 'jsaba-new-tab';
		}

		// Add item
		$wp_admin_bar->add_menu( $menu_item );
	}

}  // end of main function


add_action( 'wp_head', 'ddw_jigoshop_aba_admin_style' );
add_action( 'admin_head', 'ddw_jigoshop_aba_admin_style' );
/**
 * Add the styles for new WP Admin Bar entry
 * 
 * @since 1.0
 */
function ddw_jigoshop_aba_admin_style() {
	if ( ! is_admin_bar_showing() )
		return;

	?>
	<style type="text/css">
		/* Show first level icon - prior WordPress 3.3 */
		#wpadminbar .icon-jigoshop > a {
			background: url(<?php echo plugins_url( 'jigoshop/assets/images/icons/jigoshop-icon.png', dirname(__FILE__) ); ?>) no-repeat 0.85em 50% transparent;
			padding-left: 30px;
		}
		/* Show first level icon - WordPress 3.3 or higher */
		#wpadminbar.nojs .ab-top-menu > li.menupop.icon-jigoshop:hover > .ab-item,
		#wpadminbar .ab-top-menu > li.menupop.icon-jigoshop.hover > .ab-item,
		#wpadminbar.nojs .ab-top-menu > li.menupop.icon-jigoshop > .ab-item,
		#wpadminbar .ab-top-menu > li.menupop.icon-jigoshop > .ab-item {
      			 background-image: url(<?php echo plugins_url( 'jigoshop/assets/images/icons/jigoshop-icon.png',
dirname(__FILE__) ); ?>);
			background-repeat: no-repeat;
			background-position: 0.85em 50%;
			padding-left: 30px;
		}
		#wp-admin-bar-ddw-jigoshop-settings,
		#wp-admin-bar-ddw-jigoshop-extensions {
    			border-top: 1px solid;
		}
		#wp-admin-bar-ddw-jigoshop-forum-de a:link {
			background: #f4f4f4;
		}
		#wp-admin-bar-ddw-jigoshop-forum-de a:hover {
			background: inherit;
		}
	</style>
	<?php
}
